==> jc-1.4.0.tar.gz: javax/swing/text/StyledEditorKit__24StyledTextAction.h <==
// public abstract class javax.swing.text.StyledEditorKit$StyledTextAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 269e09938263c482 javax_swing_text_StyledEditorKit__24StyledTextAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_TextAction

#include "javax/swing/text/TextAction.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24StyledTextAction_H_
#define _JC_javax_swing_text_StyledEditorKit__24StyledTextAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JEditorPane$object;
struct _jc_javax_swing_text_AttributeSet$object;
struct _jc_javax_swing_text_StyledDocument$object;
struct _jc_javax_swing_text_StyledEditorKit$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$refs	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$nonrefs	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtable	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtype	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_javax_swing_JEditorPane$object *_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$getEditor$8a7dcc2e0aa87d53(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
extern struct _jc_object *_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$getStyledDocument$43dab697ea709deb(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *);
extern struct _jc_javax_swing_text_StyledEditorKit$object *_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$getStyledEditorKit$925ea7f67122e308(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *);
extern void _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$setCharacterAttributes$feace32ab2df4ab4(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *, struct _jc_object *, jboolean);
extern void _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$setParagraphAttributes$0a70c5738bceb655(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *, struct _jc_object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method_info$getEditor$8a7dcc2e0aa87d53;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method_info$getStyledDocument$43dab697ea709deb;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method_info$getStyledEditorKit$925ea7f67122e308;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method_info$setCharacterAttributes$feace32ab2df4ab4;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method_info$setParagraphAttributes$0a70c5738bceb655;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods {
	struct _jc_javax_swing_JEditorPane$object	*(*getEditor$8a7dcc2e0aa87d53)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
	struct _jc_object	*(*getStyledDocument$43dab697ea709deb)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *);
	struct _jc_javax_swing_text_StyledEditorKit$object	*(*getStyledEditorKit$925ea7f67122e308)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *);
	void	(*setCharacterAttributes$feace32ab2df4ab4)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *, struct _jc_object *, jboolean);
	void	(*setParagraphAttributes$0a70c5738bceb655)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *, struct _jc_object *, jboolean);
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	javax_swing_text_StyledEditorKit__24StyledTextAction;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$refs {
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledTextAction;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object {
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtype _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24StyledTextAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24StyledTextAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/StyledEditorKit__24StyledTextAction.h <==
// public abstract class javax.swing.text.StyledEditorKit$StyledTextAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 269e09938263c482 javax_swing_text_StyledEditorKit__24StyledTextAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_TextAction

#include "javax/swing/text/TextAction.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24StyledTextAction_H_
#define _JC_javax_swing_text_StyledEditorKit__24StyledTextAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JEditorPane$object;
struct _jc_javax_swing_text_AttributeSet$object;
struct _jc_javax_swing_text_StyledDocument$object;
struct _jc_javax_swing_text_StyledEditorKit$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$refs	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$nonrefs	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtable	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtype	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_JEditorPane$object *_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$getEditor$8a7dcc2e0aa87d53(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$getStyledDocument$43dab697ea709deb(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_text_StyledEditorKit$object *_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$getStyledEditorKit$925ea7f67122e308(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$setCharacterAttributes$feace32ab2df4ab4(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method$setParagraphAttributes$0a70c5738bceb655(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method_info$getEditor$8a7dcc2e0aa87d53;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method_info$getStyledDocument$43dab697ea709deb;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method_info$getStyledEditorKit$925ea7f67122e308;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method_info$setCharacterAttributes$feace32ab2df4ab4;
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$method_info$setParagraphAttributes$0a70c5738bceb655;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods {
	struct _jc_javax_swing_JEditorPane$object	*(*getEditor$8a7dcc2e0aa87d53)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getStyledDocument$43dab697ea709deb)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_text_StyledEditorKit$object	*(*getStyledEditorKit$925ea7f67122e308)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *) _JC_JCNI_ATTR;
	void	(*setCharacterAttributes$feace32ab2df4ab4)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;
	void	(*setParagraphAttributes$0a70c5738bceb655)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object *, struct _jc_javax_swing_JEditorPane$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	javax_swing_text_StyledEditorKit__24StyledTextAction;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$refs {
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledTextAction;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$object {
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vtype _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24StyledTextAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24StyledTextAction_H_ */
